package Dist::Zilla::Plugin::Mercurial;
{
  $Dist::Zilla::Plugin::Mercurial::VERSION = '0.02';
}

use strict;
use warnings;

# ABSTRACT: foo

1;

__END__

=pod

=head1 NAME

Dist::Zilla::Plugin::Mercurial - foo

=head1 VERSION

version 0.02

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Dave Rolsky.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
